Learn R Programming

eudata (version 0.1.3)

get_latest_files: Retrieve the latest files from the API

Description

This function retrieves the files belonging to the latest version of the given dataset. When the dataset is not updated the cached version is returned.

Usage

get_latest_files(api)

Value

A named list of files.

Arguments

api

An endpoint to the dataset.

Examples

Run this code
get_latest_files(get_topic("Postal"))$csv

Run the code above in your browser using DataLab