powered by
This function retrieves the files belonging to the latest version of the given dataset. When the dataset is not updated the cached version is returned.
get_latest_files(api)
A named list of files.
An endpoint to the dataset.
get_latest_files(get_topic("Postal"))$csv
Run the code above in your browser using DataLab